@@ -166,11 +166,17 @@ class KubeModel(ABC):
         weight_key = f'{job_id}:optimizer:{func_id}' 
 
         if  self._redis_client.exists(weight_key):
+            epoch = self.args.epoch
+            weight_key_print = f'{job_id}:print:{func_id}' 
+            value = f'{job_id}:print:{func_id}/{epoch}' 
+            self._redis_client.set(weight_key_print, value)
+
             pickled_val = self._redis_client.get(weight_key)
             opt_states = pickle.loads(pickled_val)  
             self.optimizer.load_state_dict(opt_states)
 
 
+
     def _save_redis_test(self):
         """
         Saves the optimizer to the redis
@@ -182,10 +188,9 @@ class KubeModel(ABC):
         self.logger.debug("Saving optimizer to the database")
 
         weight_key = f'{job_id}:test:{func_id}' 
-        value = f'{job_id}:optimizer:{func_id}/{epoch}' 
+        value = f'{job_id}:test:{func_id}/{epoch}' 
         self._redis_client.set(weight_key, value)
 
-        self.logger.debug('Saved optimizer to the database')
 
     def _load_redis_test(self):
         """
